library(startR)
library(s2dv)
library(CSTools)
library(lubridate)

target_grid <- '/esarchive/recon/ecmwf/era5/monthly_mean/tas_f1h/tas_200002.nc'
method <- 'con'
lonmin <- -22
lonmax <- 45
latmin <- 27
latmax <- 72
#lonmin <- -11.5
#lonmax <- 5.35
#latmin <- 35.1
#latmax <- 44.1
extra <- 0
sdates <- c('20000201')

# use the same obs Start() call
obs <- Start(dat = '/esarchive/recon/ecmwf/era5/monthly_mean/$var$_f1h/$var$_$sdate$.nc',
             var = 'tas', time = indices(1), lat = values(list(latmin, latmax)),
             lat_reorder = Sort(decreasing = T), lon = values(list(lonmin, lonmax)),
             lon_reorder = CircularSort(-180, 180), sdate = format(ymd(sdates), "%Y%m"),
             synonims = list(var = c('var','variable'), lon = c('lon', 'longitude'),
             lat = c('lat', 'latitude')), return_vars = list(lat = 'dat', lon = 'dat'),
             retrieve = TRUE)

# Load coarse model data
exp <- Start(dat = '/esarchive/exp/ecmwf/system5c3s/monthly_mean/$var$_f6h/$var$_$sdate$.nc',
             var = 'tas', time = indices(1), member = indices(1), sdate = sdates,
             lat = values(list(latmin - extra, latmax + extra)), lat_reorder = Sort(decreasing = T),
             lon = values(list(lonmin - extra, lonmax + extra)), lon_reorder = CircularSort(-180, 180),
             synonims = list(var = c('var','variable'), lon = c('lon', 'longitude'),
             lat = c('lat', 'latitude'), member = c('member','ensemble')),
             return_vars = list(lat = 'dat', lon = 'dat'),
             retrieve = TRUE)


exp <- drop(exp)
obs <- drop(obs)

dim(exp) # bigger than the real-desired region
#lat lon 
# 11  19 
dim(obs)
#lat lon 
# 32  60 

lons_obs <- as.vector(attr(obs, 'Variables')$dat1$lon)
lats_obs <- as.vector(attr(obs, 'Variables')$dat1$lat)
lons_exp <- as.vector(attr(exp, 'Variables')$dat1$lon)
lats_exp <- as.vector(attr(exp, 'Variables')$dat1$lat)


west <- lons_obs[1]
east <- lons_obs[length(lons_obs)]
south <- lats_obs[1]
north <- lats_obs[length(lats_obs)]

# Regrid with CDORemap
exp_interpolated <- s2dv::CDORemap(data_array = exp,
                             lats = attr(exp, "Variables")$dat1$lat,
                             lons = attr(exp, "Variables")$dat1$lon,
                             grid = target_grid,
                             method = method,
                             #crop = c(lonmin , lonmax, latmin, latmax))
                             crop = c(west, east, south, north))
dim(exp_interpolated$data)
#lat lon 
# 32  60 

dim(obs)
#lat lon 
# 32  60 

summary(as.vector(exp_interpolated$data))
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  276.0   279.8   283.7   283.0   286.3   288.7 

